      SUBROUTINE HLEIGT (JT,JTMAX,LPRNT,LRERR,NCEIG,NVB,
     &                   BETA,EPS,HNRM,ST,TB,TTB,FULL)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLEIGT solves the reduced eigenproblem                           *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JT    (sii) : current dimension of the reduced eigenproblem      *
C*    JTMAX (sii) : maximum dimension of the reduced eigenproblem      *
C*    LPRNT (sii) : printing code                                      *
C*    LRERR (sio) : error code                                         *
C*    NCEIG (sio) : number of solutions converged                      *
C*    NVB   (sii) : dimension of (BETA)                                *
C*    BETA  (ari) : matrix (BETA) in (R)=(Q)*(BETA) at j-th step       *
C*    EPS   (sri) : roundoff unit                                      *
C*    HNRM  (sri) : norm of the hermitian matrix                       *
C*    ST    (aro) : eigenvectors of the reduced eigenproblem           *
C*    TB    (ari) : block tridiagonal matrix                           *
C*    TTB   (aro) : copy of (TB)                                       *
C*                  - its 1st column returns the eigenvalues of (TB)   *
C*                  - its 2nd column returns the residual norms        *
C*    FULL  (sli) : flag to specify the part of (ST) to be considered  *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    HLPRT1,HLRCHK,IDENTY,IMTQL                                       *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JT,JTMAX,LPRNT,LRERR,NCEIG,NVB
      DOUBLE PRECISION BETA(NVB,NVB),EPS,HNRM,ST(JT,JT),
     &                 TB(JTMAX,*),TTB(JT,*)
      LOGICAL          FULL
C
C==== local variables ==================================================
C
      INTEGER          I,J,LINE
      DOUBLE PRECISION BJMIN
      LOGICAL          CONV
C
C**** executable statements ********************************************
C
                  LINE = JT - NVB + 1
      IF ( FULL ) LINE = 1
C
C.... copy (TB) into (TTB) .............................................
C
      DO 010 I = 1,NVB+1
	 DO 020 J = 1,JT
	    TTB(J,I) = TB(J,I)
  020    CONTINUE
  010 CONTINUE
C
C.... initialization of (ST) ...........................................
C
      CALL IDENTY (JT,ST)
C
C.... transformation of (TTB) to a tridiagonal form ....................
C
C     IF ( NVB .NE. 1 ) CALL BANDRD (LINE,NVB,JT,TTB,ST)
C
                        TTB(JT,2) = 0.0D0
C
C.... solution of the reduced eigenproblem using Givens method .........
C
      CALL IMTQL (LINE,JT,TTB(1,1),TTB(1,2),ST,EPS,CONV)
C
C.... searching for converged solutions ................................
C
      IF      ( .NOT.CONV ) THEN
              LRERR = LRERR + 2**07
      ELSE IF ( .NOT.FULL ) THEN
              CALL HLRCHK (JT,NCEIG,NVB,BETA,BJMIN,EPS,HNRM,
     &                     TTB(1,2),ST,TTB(1,1))
              CALL HLPRT1 (JT,LPRNT,BJMIN,TTB(1,2),TTB(1,1)) 
      END IF
C
      RETURN
C
C**** end of HLEIGT ****************************************************
C
      END
