      SUBROUTINE HLLORT (JL,JLMAX,LBLAS,LWARN,N,NVB,ALPHA,BETAQ,BETAR,
     &                   Q,R,WORK,ALPNRM,BETNRM,EPS,REPS) 
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLLORT performs a partial reorthogonalization                    *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JL     (sii) : current step                                      *
C*    JLMAX  (sii) : maximum number of steps                           *
C*    LBLAS  (aii) : BLAS level setting                                *
C*    LWARN  (sio) : warning code                                      *
C*    N      (sii) : dimension of the problem                          *
C*    NVB    (sii) : number of vectors in a block                      *
C*    ALPHA  (acb) : matrix (Q')*(R) at step JL                        *
C*    BETAQ  (acb) : matrix (BETA) in (R)=(Q)*(BETA) at step JL-1      *
C*    BETAR  (acb) : matrix (BETA) in (R)=(Q)*(BETA) at step JL        *
C*    Q      (acb) : current Lanczos  vector(s)                        *
C*    R      (acb) : current residual vector(s)                        *
C*    WORK   (acw) : work array                                        *
C*    ALPNRM (aro) : extreme singular values of (ALPHA)                *
C*    BETNRM (aro) : extreme singular values of (BETA)                 *
C*    EPS    (sri) : roundoff unit                                     *
C*    REPS   (sri) : square root of the roundoff unit                  *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    MTXNRM,QBFCTR,QTBR,RQALPH,UDALPH                                 *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JL,JLMAX,LBLAS(4),LWARN,N,NVB     
      COMPLEX*16       ALPHA(NVB,NVB),BETAQ(NVB,NVB),BETAR(NVB,NVB),
     &                 Q(N,NVB),R(N,NVB),WORK(*)
      DOUBLE PRECISION ALPNRM(JLMAX,2),BETNRM(JLMAX,2),EPS,REPS
C
C==== local variables ==================================================
C
      INTEGER          I,IWRK1,IWRK2,IWRK3
      DOUBLE PRECISION WMAX
C
C**** executable statements ********************************************
C
      IWRK1 = 1
      IWRK2 = IWRK1 + NVB
      IWRK3 = IWRK2 + NVB*NVB
C
C.... update (R) and (Q) ...............................................
C
      CALL QBFCTR (JL-1,JLMAX,LBLAS,LWARN,N,NVB,BETAQ,Q,WORK(IWRK2),
     &             WORK(IWRK1),WORK(IWRK3),ALPNRM(JL-1,1),
     &             BETNRM(JL  ,2),BETNRM(JL  ,1),EPS)
C
      CALL QBFCTR (JL  ,JLMAX,LBLAS,LWARN,N,NVB,BETAR,R,WORK(IWRK2),
     &             WORK(IWRK1),WORK(IWRK3),ALPNRM(JL  ,1),
     &             BETNRM(JL+1,2),BETNRM(JL+1,1),EPS)
C
      IF ( LWARN .NE. 0 ) GO TO 020
C
C.... local orthogonalization repeated up to NVB times, if necessary ...
C
      DO 010 I = 1,NVB
C
C....... reorthogonalization of (R) against (Q) ........................
C
         CALL QTBR   (Q,R,WORK,WMAX,LBLAS(2),N,NVB)
C
         CALL RQALPH (R,Q,WORK,LBLAS(3),N,NVB)
C
C....... (ALPHA) updating ..............................................
C
         CALL UDALPH (NVB,ALPHA,BETAR,WORK)
C
         CALL MTXNRM (NVB,ALPHA,WORK,EPS,ALPNRM(JL,2),ALPNRM(JL,1))
C
C....... (R)=(Q)*(BETA) updating .......................................
C
         CALL QBFCTR (JL,JLMAX,LBLAS,LWARN,N,NVB,BETAR,R,WORK(IWRK2),
     &                WORK(IWRK1),WORK(IWRK3),ALPNRM(JL,1),
     &                BETNRM(JL+1,2),BETNRM(JL+1,1),EPS)
C
         IF ( ( WMAX .LE. REPS ) .OR. ( LWARN .NE. 0 ) ) GO TO 020
C
  010 CONTINUE
C
  020 RETURN
C
C**** end of HLLORT ****************************************************
C
      END
