      SUBROUTINE HLORTH (JT,LN,N,BASIS,EPS)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLORTH computes and prints the basis orthogonality level         *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JT    (sii) : dimension of the projection                        *
C*    LN    (sii) : first dimension of BASIS                           *
C*    N     (sii) : dimension of each vector                           *
C*    BASIS (aci) : stores the Lanczos vectors                         *
C*    EPS   (sri) : roundoff unit                                      *
C*                                                                     *
C*  - BLAS kernel:                                                     *
C*    ZGEMM                                                            *
C*                                                                     *
C*  - INTRINSIC FUNCTIONS :                                            *
C*    CDABS,DABS,DBLE,DLOG10,IDNINT                                    *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JT,LN,N
      COMPLEX*16       BASIS(LN,*)
      DOUBLE PRECISION EPS
C
C==== local variables ==================================================
C
      INTEGER          JTMAX 
      PARAMETER        (JTMAX=25)
C
      INTEGER          I,J
      COMPLEX*16       CMPLX0,CMPLX1,IDENTY(JTMAX,JTMAX)
C
C==== intrinsic functions ==============================================
C
      INTRINSIC        CDABS,DABS,DBLE,DLOG10,IDNINT
C
C**** executable statements ********************************************
C
      CMPLX0 = ( 0.0D0, 0.0D0 )
      CMPLX1 = ( 1.0D0, 0.0D0 )
C
      IF ( JT .GT. JTMAX ) THEN
         WRITE (*,'(/A )') 'WARNING: JL greater than maximum allowed'
         WRITE (*,'( A )') '         basis orthogonality not checked'
      ELSE
         WRITE (*,'(/A/)') '* basis orthogonality level check *' 
         CALL ZGEMM ('C','N',JT,JT,N,CMPLX1,BASIS,LN,
     &                BASIS,LN,CMPLX0,IDENTY,JTMAX)
         DO 010 I = 1,JT
            DO 020 J = 1,JT
               IF ( CDABS(IDENTY(I,J)) .LT. EPS ) IDENTY(I,J) = EPS
               IDENTY(I,J) = DABS(DLOG10(CDABS(IDENTY(I,J))))
  020       CONTINUE
            WRITE (*,'(25I3)') (IDNINT(DBLE(IDENTY(I,J))),J=1,JT)
  010    CONTINUE
      END IF
C
      RETURN
C
C**** end of HLORTH ****************************************************
C
      END
