      SUBROUTINE HLPORT (JL,LBLAS,LN,N,NVB,BASIS,Q,R,
     &                   ZETA,EPS1,ETAQ,ETAR)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLPORT performs a partial reorthogonalization                    *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JL    (sii) : current step                                       *
C*    LBLAS (aii) : BLAS level setting                                 *
C*    LN    (sii) : first dimension of (BASIS)                         *
C*    N     (sii) : dimension of the problem                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*    BASIS (aci) : stores the Lanczos vectors                         *
C*    Q     (acb) : current Lanczos  vector(s)                         *
C*    R     (acb) : current residual vector(s)                         *
C*    ZETA  (acw) : work array                                         *
C*    EPS1  (sri) : roundoff unit * sqrt(N)                            *
C*    ETAR  (arb) : orthogonality bounds among (R) and Lanczos vectors *
C*    ETAQ  (arb) : orthogonality bounds among (Q) and Lanczos vectors *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    QTBR,RQALPH                                                      *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JL,LBLAS(4),LN,N,NVB     
      COMPLEX*16       BASIS(LN,*),Q(N,NVB),R(N,NVB),ZETA(*)
      DOUBLE PRECISION EPS1,ETAQ(*),ETAR(*)
C
C==== local variables ==================================================
C
      INTEGER          I
      DOUBLE PRECISION ZMAX
C
C**** executable statements ********************************************
C
C.... perform a partial orthogonalization ..............................
C
      ETAR(JL) = EPS1
      ETAQ(JL) = EPS1
C
      DO 010 I = 1,JL-1   
C
         ETAR(I) = EPS1
         ETAQ(I) = EPS1
C
C....... orthogonalization of (Q) against old (Q) ......................
C
         CALL QTBR   (BASIS(1,I),Q,ZETA,ZMAX,LBLAS(2),N,NVB)
C
         CALL RQALPH (Q,BASIS(1,I),ZETA,LBLAS(3),N,NVB)
C
C....... orthogonalization of (R) against old (Q) ......................
C
         CALL QTBR   (BASIS(1,I),R,ZETA,ZMAX,LBLAS(2),N,NVB)
C
         CALL RQALPH (R,BASIS(1,I),ZETA,LBLAS(3),N,NVB)
C
  010 CONTINUE
C
      RETURN
C
C**** end of HLPORT ****************************************************
C
      END
