      SUBROUTINE HLPSET (IW,JL,JLMAX,JTMAX,LBLAS,LFLAG,LN,LPRNT,LPSET,
     &                   LRERR,LWARN,N,NCEIG,NREIG,NRORT,NVB,
     &                   Q,EPS,EPS1,REPS,WORK)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLPSET initializes the Hermitian-Lanczos algorithm               *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    IW    (aio) : pointers for the work array                        *
C*    JL    (sio) : current step                                       *
C*    JLMAX (sio) : maximum number of steps                            *
C*    JTMAX (sio) : maximum dimension of the projection                *
C*    LBLAS (aio) : BLAS level setting                                 *
C*    LFLAG (sio) : flag for the Hermitian-Lanczos algorithm           *
C*    LN    (sio) : leading dimension for two-dimensional arrays       *
C*    LPRNT (sio) : printing code                                      *
C*    LPSET (aii) : basic data for the Hermitian-Lanczos algorithm     *
C*    LRERR (sio) : error code                                         *
C*    LWARN (sio) : warning code                                       *
C*    N     (sio) : dimension of the problem                           *
C*    NCEIG (sio) : number of solutions converged                      *
C*    NREIG (sio) : number of solutions required                       *
C*    NRORT (sio) : number of reorthogonalizations                     *
C*    NVB   (sio) : number of vectors in a block                       *
C*    Q     (acb) : starting vector                                    *
C*    EPS   (sro) : roundoff unit                                      *
C*    EPS1  (sro) : roundoff unit * sqrt(N)                            *
C*    REPS  (sro) : square root of EPS                                 *
C*    WORK  (arb) : work array                                         *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    HLHEAD,HLRAND                                                    *
C*                                                                     *
C*  - BLAS kernel :                                                    *
C*    DSCAL                                                            *
C*                                                                     *
C*  - INTRINSIC FUNCTIONS :                                            *
C*    DSQRT,FLOAT,SQRT                                                 *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          IW(*),JL,JLMAX,JTMAX,LBLAS(*),LFLAG,LN,LPRNT,
     &                 LPSET(*),LRERR,LWARN,N,NCEIG,NREIG,NRORT,NVB
      COMPLEX*16       Q(*)
      DOUBLE PRECISION EPS,EPS1,REPS,WORK(*)
C
C==== intrinsic functions ==============================================
C
      INTRINSIC        DSQRT,FLOAT,SQRT
C
C**** executable statements ********************************************
C
C.... set basic parameters .............................................
C
      IF ( LPSET(1) .LE. 0 ) LRERR = LRERR + 2**02
      IF ( LPSET(2) .LE. 0 ) LRERR = LRERR + 2**03
      IF ( LPSET(3) .LE. 0 ) LRERR = LRERR + 2**04
      IF ( LPSET(4) .LT. 0 ) LRERR = LRERR + 2**05
      IF ( LPSET(5) .LT. 0 ) LRERR = LRERR + 2**06
C
      IF ( LRERR  .NE. 0 ) RETURN
C
      N     = LPSET(1)
      NREIG = LPSET(2)
      JLMAX = LPSET(3)
      LPRNT = LPSET(4)
      LN    = LPSET(5)
C
      IF ( NREIG .GT. N ) LRERR = LRERR + 2**03 
      IF ( JLMAX .GT. N ) LRERR = LRERR + 2**04 
C
      IF ( LRERR .NE. 0 ) RETURN
C
      IF ( N .EQ. 1 ) THEN
         LWARN = LWARN + 2**01
         LFLAG = -1
         RETURN
      END IF
C
      JTMAX = JLMAX
      NCEIG = 0
      NRORT = 0
      LFLAG = 1
      NVB   = 1
      JL    = 0
C
C.... set roundoff units ...............................................
C
      EPS   = 2.0D0**(-52)
      EPS1  = EPS*SQRT(FLOAT(N))
      REPS  = DSQRT(EPS)         
C
C.... set BLAS level ...................................................
C
      LBLAS(1) = 1
      LBLAS(2) = 1
      LBLAS(3) = 1
      LBLAS(4) = 1
C
C.... pointers for the work array ......................................
C
      CALL DSCAL ((JLMAX+10)*JLMAX,0.0D0,WORK,1)
C
C.... pointer for (ETA) ................................................
      IW(1) = 1
C.... pointer for (ALPNRM) .............................................
      IW(2) = IW(1) + JLMAX*2
C.... pointer for (BETNRM) .............................................
      IW(3) = IW(2) + JLMAX*2
C.... pointer for (TTB) ................................................
      IW(4) = IW(3) + JLMAX*2
C.... pointer for (TB) .................................................
      IW(5) = IW(4) + JLMAX*2
C.... pointer for (ST) .................................................
      IW(6) = IW(5) + JLMAX*2
C     
C.... check the starting vector ........................................
C
      CALL HLHEAD (JLMAX,LPRNT,N,NREIG,EPS)
C
      CALL HLRAND (N,NVB,Q)           
C
      WORK(1      ) = EPS1
      WORK(2      ) = EPS1
      WORK(1+JLMAX) = EPS1
      WORK(2+JLMAX) = EPS1
C
      RETURN  
C
C**** end of HLPSET ****************************************************
C
      END
