      SUBROUTINE HLRCHK (JT,NCEIG,NVB,BETA,BJMIN,EPS,HNRM,NORM,S,TETA)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLRCHK checks the convergence of solutions                       *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JT    (sii) : current dimension of the reduced eigenproblem      *
C*    NCEIG (sio) : number of solutions converged                      *
C*    NVB   (sii) : dimension of (BETA)                                *
C*    BETA  (ari) : matrix (BETA) in (R)=(Q)*(BETA) at j-th step       *
C*    BJMIN (sro) : threshold residual for convergence                 *
C*    EPS   (sri) : roundoff unit                                      *
C*    HNRM  (sri) : norm of the hermitian matrix                       *
c*    NORM  (aro) : residual norms at j-th step                        *
C*    ST    (ari) : eigenvectors of the reduced eigenproblem           *
C*    TETA  (ari) : eigenvalues of the reduced eigenproblem            *
C*                                                                     *
C*  - SUBPROGRAM :                                                     *
C*    RESNRM                                                           *
C*                                                                     *
C*  - INTRINSIC FUNCTIONS :                                            *
C*    DABS,DMAX1,DMIN1                                                 *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JT,NCEIG,NVB
      DOUBLE PRECISION BETA(*),EPS,HNRM,NORM(*),S(JT,JT),TETA(JT)
C
C==== local variables ==================================================
C
      INTEGER          I
      DOUBLE PRECISION BJMIN,ENORMH
C
C==== subprogram =======================================================
C
      DOUBLE PRECISION RESNRM
C
C==== intrinsic functions ==============================================
C
      INTRINSIC        DABS,DMAX1,DMIN1
C
C**** executable statements ********************************************
C
      NCEIG  = 0
C
C.... Euclidean norm of the matrix .....................................
C
      IF ( HNRM .LE. 0.0D0 ) THEN
         ENORMH = DMAX1(DABS(TETA( 1)),DABS(TETA(JT)))
      ELSE
         ENORMH = HNRM
      END IF
C
C.... threshold for convergence ........................................
C
      BJMIN = DMIN1(1.0D-5,ENORMH*EPS**0.5)
C
C.... check convergence, NCEIG is the number of converged solutions ....
C
      DO 010 I = 1,JT   
         NORM(I) = RESNRM(NVB,BETA,S(JT,I))
	 IF ( NORM(I) .LE. BJMIN ) THEN
            NCEIG = NCEIG + 1
         ELSE
	    NORM(I) = -NORM(I)
         END IF
  010 CONTINUE
C
      RETURN
C
C**** end of HLRCHK ****************************************************
C
      END
