      SUBROUTINE HLREND (JL,LFLAG,LPRNT,LRERR,LWARN,LN,N,NCEIG,
     &                   NRORT,BASIS,EPS,EIG,RNRM)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLREND finishes the Hermitian-Lanczos run                        *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JL    (sii) : number of steps                                    *
C*    LFLAG (sii) : flag for the Hermitian-Lanczos algorithm           *
C*    LPRNT (sii) : printing code                                      *
C*    LRERR (sii) : error code                                         *
C*    LWARN (sii) : warning code                                       *
C*    LN    (sii) : first dimension of BASIS                           *
C*    N     (sii) : dimension of the problem                           *
C*    NCEIG (sii) : number of solutions converged                      *
C*    NRORT (sii) : number of reorthogonalizations                     *
C*    BASIS (aci) : stores the Lanczos vectors                         *
C*    EPS   (sri) : roundoff unit                                      *
C*    EIG   (aro) : eigenvalue approximations                          *
C*    RNRM  (aro) : residual norms of the eigenpairs                   *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    HLERRM,HLORTH,HLPRT2,HLWARN,SIBTST                               *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JL,LFLAG,LN,LPRNT,LRERR,LWARN,N,NCEIG,NRORT
      COMPLEX*16       BASIS(LN,*)
      DOUBLE PRECISION EPS,EIG(*),RNRM(*)
C
C==== subprogram =======================================================
C
      LOGICAL          SIBTST
C
C**** executable statements ********************************************
C
C.... warning messages .................................................
C
      IF ( SIBTST(6,LPRNT) ) THEN
         IF ( LWARN .NE. 0 ) CALL HLWARN (LWARN)
      END IF
C
C.... error messages ...................................................
C
      IF ( SIBTST(7,LPRNT) ) THEN 
         IF ( LRERR .NE. 0 ) THEN
            CALL HLERRM (LRERR)
            LFLAG = -1
         END IF
      END IF
C
C.... basis orthogonality check ........................................
C
      IF ( SIBTST(8,LPRNT) ) THEN
         IF ( JL .GT. 1 ) CALL HLORTH (JL,LN,N,BASIS,EPS)
      END IF
C
C.... statistics .......................................................
C
      IF ( SIBTST(1,LPRNT) ) THEN 
         CALL HLTAIL (JL,LFLAG,LRERR,LWARN,NCEIG,NRORT)
      END IF
C
C.... print eigenvalues ................................................
C
      IF ( SIBTST(2,LPRNT) ) THEN
         IF ( NCEIG .NE. 0 ) CALL HLPRT2 (JL,EIG,RNRM)
      END IF
C
      RETURN
C
C**** end of HLREND ****************************************************
C
      END
