      SUBROUTINE HLRITZ (JT,JTMAX,LPRNT,LWARN,LN,N,NVB,BASIS,
     &                   X,Y,EPS,EIG,RNRM,TB,TTB,ST)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLRITZ computes the eigenvectors of (H)*(x)-eig*(x)=0            *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JT    (sii) : dimension of the reduced problem                   *
C*    JTMAX (sii) : maximum dimension of the reduced problem           *
C*    LPRNT (sii) : level of printing                                  *
C*    LWARN (sio) : warning code                                       *
C*    LN    (sii) : first dimension of BASIS and X                     *
C*    N     (sii) : dimension of the problem                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*    BASIS (aci) : stores the Lanczos vectors                         *
C*    X     (aco) : stores the eigenvectors                            *
C*    Y     (acw) : work array                                         *
C*    EPS   (sri) : roundoff unit                                      *
C*    EIG   (ari) : eigenvalues approximations                         *
C*    RNRM  (ari) : residual norms of the eigenpairs                   *
C*    TB    (arw) : block tridiagonal matrix                           *
C*    TTB   (arw) : copy of (TB)                                       *
C*    ST    (arw) : eigenvectors of the reduced problem                *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    HLEIGT,SIBTST                                                    *
C*                                                                     *
C*  - BLAS kernel :                                                    *
C*    ZGEMV                                                            *
C*                                                                     *
C*  - INTRINSIC FUNCTION:                                              *
C*    DCMPLX                                                           *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JT,JTMAX,LN,LPRNT,LWARN,N,NVB
      COMPLEX*16       BASIS(LN,*),X(LN,*),Y(*)
      DOUBLE PRECISION EIG(*),EPS,RNRM(*),ST(JT,JT),TB(*),TTB(*)
C
C==== local variables ==================================================
C              
      INTEGER          I,IDUMMY,J,NX
      DOUBLE PRECISION RDUMMY
      COMPLEX*16       ONE,ZERO
C
C==== subprogram =======================================================
C              
      LOGICAL          SIBTST
C
C==== intrinsic function ===============================================
C              
      INTRINSIC        DCMPLX
C
C**** executable statements ********************************************
C
      NX   = 0
C
      ONE  = ( 1.0D0, 0.0D0 )
      ZERO = ( 0.0D0, 0.0D0 )
C
C.... solve the reduced eigenproblem ...................................
C
      CALL HLEIGT (JT,JTMAX,IDUMMY,IDUMMY,IDUMMY,NVB,RDUMMY,
     &             EPS,RDUMMY,ST,TB,TTB,.TRUE.)
C
C.... compute the eigenvectors .........................................
C
      DO 010 I = 1,JT
         IF ( RNRM(I) .GT. 0.0D0 ) THEN
            NX = NX + 1
            DO 020 J = 1,JT
               Y(J) = DCMPLX(ST(J,I),0.0D0)
  020       CONTINUE
            CALL ZGEMV ('N',N,JT,ONE,BASIS,LN,Y,1,ZERO,X(1,NX),1)
            IF ( SIBTST(3,LPRNT) ) WRITE (*,2500) EIG(I),(X(J,NX),J=1,N)
         END IF
  010 CONTINUE
C
      IF ( NX .EQ. 0 ) THEN
         IF ( .NOT.SIBTST(4,LWARN) ) LWARN = LWARN + 2**04
      END IF
C
 2500 FORMAT (/'eigenvector related to the eigenvalue: ',1P,E11.4,
     &        1X,25('-'),/(3(2E12.4,:,2X)))
C
      RETURN
C
C**** end of HLRITZ ****************************************************
C
      END
