      SUBROUTINE HLSTEP (JL,JLMAX,JT,JTMAX,LBLAS,LFLAG,LN,LPRNT,LRERR,
     &                   LWARN,N,NCEIG,NREIG,NRORT,NVB,BASIS,Q,R,
     &                   HNRM,ETA,ALPNRM,BETNRM,TTB,TB,ST,
     &                   EPS,EPS1,REPS,EIG,RNRM)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLSTEP performs a step of the Hermitian-Lanczos algorithm        *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JL     (sii) : current step                                      *
C*    JLMAX  (sii) : maximum number of steps                           *
C*    JT     (sio) : current dimension of the reduced problem          *
C*    JTMAX  (sii) : maximum dimension of the reduced problem          *
C*    LBLAS  (aii) : BLAS level setting                                *
C*    LFLAG  (sio) : flag for the Hermitian-Lanczos algorithm          *
C*    LN     (sio) : first dimension of (BASIS)                        *
C*    LPRNT  (sii) : printing code                                     *
C*    LRERR  (sio) : error code                                        *
C*    LWARN  (sio) : warning code                                      *
C*    N      (sii) : dimension of the problem                          *
C*    NCEIG  (sio) : number of solutions converged                     *
C*    NREIG  (sii) : number of solutions required                      *
C*    NRORT  (sio) : number of reorthogonalizations                    *
C*    NVB    (sii) : number of vectors in a block                      *
C*    BASIS  (acb) : stores the Lanczos vectors                        *
C*    Q      (acb) : Lanczos  vector                                   *
C*    R      (acb) : residual vector                                   *
C*    HNRM   (sri) : norm of the hermitian matrix                      *
C*    ETA    (arw) : orthogonality control bounds                      *
C*    ALPNRM (arw) : extreme singular values of (ALPHA)s               *
C*    BETNRM (arw) : extreme singular values of (BETA)s                *
C*    TTB    (arw) : copy of (TB)                                      *
C*    TB     (acw) : block tridiagonal matrix                          *
C*    ST     (arw) : eigenvectors of the reduced problem               *
C*    EPS    (sri) : roundoff unit                                     *
C*    EPS1   (sri) : roundoff unit * sqrt(N)                           *
C*    REPS   (sri) : square root of EPS                                *
C*    EIG    (aro) : eigenvalue approximations                         *
C*    RNRM   (aro) : residual norms of the eigenpairs                  *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    HLEIGT,HLLORT,HLPORT,IALPHT,IBETAT,MTXNRM,                       *
C*    QBFCTR,QTBR,RQALPH,RQBETA,SIBTST,UPDETA                          *
C*                                                                     *
C*  - BLAS kernels :                                                   *
C*    DCOPY,IDAMAX,ZCOPY                                               *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JL,JLMAX,JT,JTMAX,LBLAS(4),LFLAG,LN,LPRNT,
     &                 LRERR,LWARN,N,NCEIG,NREIG,NRORT,NVB
      COMPLEX*16       BASIS(LN,*),Q(*),R(*)
      DOUBLE PRECISION ALPNRM(JLMAX,2),BETNRM(JLMAX,2),EIG(*),EPS,
     &                 EPS1,ETA(JLMAX,2),HNRM,REPS,RNRM(*),
     &                 ST(*),TB(*),TTB(*)
C
C==== local variables ==================================================
C
      INTEGER          IMXETA
      COMPLEX*16       CALPHA(1,1),CBETAQ(1,1),CBETAR(1,1),WORK(3)
      DOUBLE PRECISION ALPHA(1,1),BETAQ(1,1),BETAR(1,1),DUMMY
      LOGICAL          PORT 
C
      SAVE             ALPHA,BETAQ,BETAR,CALPHA,CBETAQ,CBETAR
C
C==== subprogram =======================================================
C
      LOGICAL          SIBTST
C
C==== BLAS kernel ======================================================
C
      INTEGER          IDAMAX
C
C**** executable statements ********************************************
C
      PORT  = .FALSE.
C
C.... compute the residual: (R)=(H)*(Q) ................................
C
      JL   = JL + 1
      JT   = JL*NVB
C
      IF ( SIBTST(4,LPRNT) ) WRITE (*,'(A,I4)')
     &                       'Hermitian-Lanczos information at step',JL
C
C.... orthogonalize (R) against the j-1 th (Q) .........................
C
      IF (JL.GT.1) CALL RQBETA (R,BASIS(1,JL-1),CBETAQ,LBLAS(1),N,NVB)
C
C.... orthogonalize (R) against the j   th (Q) .........................
C
      CALL QTBR   (Q,R,CALPHA,DUMMY,LBLAS(2),N,NVB)
C
      CALL RQALPH (R,Q,CALPHA,LBLAS(3),N,NVB)
C
      CALL MTXNRM (NVB,CALPHA,WORK,EPS,ALPNRM(JL,2),ALPNRM(JL,1))
C
C.... normalize (R) and get the next (Q) ...............................
C
      CBETAR(1,1) = ( 1.0D0, 0.0D0 )
C
      CALL QBFCTR (JL,JLMAX,LBLAS,LWARN,N,NVB,CBETAR,R,WORK(1),WORK(2),
     &             WORK(3),ALPNRM(JL,2),BETNRM(JL+1,2),
     &             BETNRM(JL+1,1),EPS)
C
C.... update orthogonality level bounds ................................
C
      CALL UPDETA (JL,ALPNRM(1,2),BETNRM(1,2),BETNRM(JL+1,1),
     &             EPS1,ETA(1,1),ETA(1,2))
C
      IMXETA = IDAMAX(JL,ETA(1,2),1)
C
C.... if required perform a partial reorthogonalization ................
C
      IF ( ETA(IMXETA,2) .GT. REPS ) THEN  
         IF ( SIBTST(5,LPRNT) ) WRITE (*,'(A,I3,1P,E13.4)') 
     &                          'reorthogonalization, max:',
     &                          IMXETA,ETA(IMXETA,2)
         CALL HLPORT (JL,LBLAS,LN,N,NVB,BASIS,Q,R,WORK,
     &                EPS1,ETA(1,1),ETA(1,2))
         NRORT = NRORT + 1
         PORT = .TRUE.
      END IF
C
C.... if required perform a local reorthogonalization ..................
C
      IF ( ( PORT ) .OR. ( NVB .GT. 1 ) ) THEN
         CALL HLLORT (JL,JLMAX,LBLAS,LWARN,N,NVB,CALPHA,CBETAQ,CBETAR,
     &                Q,R,WORK,ALPNRM,BETNRM,EPS,REPS)
      END IF
C
C.... add the j-th vector into the basis ...............................
C
      ALPHA(1,1)  = CALPHA(1,1)
      BETAQ(1,1)  = CBETAQ(1,1)
C
      IF ( JL .GT. 1 ) CALL IBETAT (JL-1,JTMAX,NVB,BETAQ,TB)
                       CALL IALPHT (JL  ,JTMAX,NVB,ALPHA,TB)
C
      CBETAQ(1,1) = CBETAR(1,1)
      BETAR(1,1)  = CBETAR(1,1)
C
      CALL ZCOPY  (N*NVB,Q,1,BASIS(1,JL),1)
      CALL ZCOPY  (N*NVB,R,1,Q,1)
C
C.... solve the reduced eigenproblem and check convergence .............
C
      CALL HLEIGT (JT,JTMAX,LPRNT,LRERR,NCEIG,NVB,BETAR,
     &             EPS,HNRM,ST,TB,TTB,.FALSE.)
C
      IF      ( LWARN .NE. 0 ) THEN
              LFLAG = 2
              IF ( NCEIG .LT. NREIG ) LWARN = LWARN + 2**05
      ELSE IF ( NCEIG .GE. NREIG ) THEN
              LFLAG = 2
      ELSE IF ( JT .EQ. JTMAX ) THEN
              LFLAG = 2
              IF ( NCEIG .EQ. 0 ) THEN
                 LWARN = LWARN + 2**03
                 LWARN = LWARN + 2**04
              ELSE
                 LWARN = LWARN + 2**05
              END IF
      END IF
C
C.... copy approximations to EIG and RNRM ..............................
C
      CALL DCOPY(JT,TTB(1   ),1,EIG ,1)
      CALL DCOPY(JT,TTB(1+JT),1,RNRM,1)
C
      RETURN 
C
C**** end of HLSTEP ****************************************************
C
      END
