      SUBROUTINE HLZDRD (LFLAG,LPSET,INFO,HNRM,EIG,RNRM,W,Q,R,BASIS,X)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    HLZDRD is the double precision user interface for hlzpack        *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    LFLAG : flag for the Hermitian-Lanczos algorithm                 *
C*            < 0, non standard exit (error condition)                 *
C*            = 0, must be used on the first call to HLZDRD            *
C*            = 1, the user must compute R=H*Q and call HLZDRD again   *
C*            = 2, NREIG, NSTEPS or an invariant subspace reached      *
C*            = 3, compute the eigenvectors                            *
C*    LPSET : holds basic data for the Hermitian-Lanczos algorithm     *
C*            LPSET(1)=N     , .gt.0, dimension of the matrix          *
C*            LPSET(2)=NREIG , .gt.0, number of eigenpairs required    *
C*            LPSET(3)=NSTEPS, .gt.0, maximum number of steps          *
C*            LPSET(4)=LPRNT , .ge.0, level of printing                *
C*            LPSET(5)=LN    , .ge.N, first dimension of X and BASIS   *
C*    INFO  : holds information about the execution                    *
C*            INFO(1)=J    , dimension of the basis                    *
C*            INFO(2)=NCEIG, number of eigenpairs converged with J     *
C*            INFO(3)=LWARN, code for warning messages                 *
C*            INFO(4)=LRERR, code for error messages                   *
C*    HNRM  : norm of H                                                *
C*    EIG   : eigenvalue approximations                                *
C*    RNRM  : residual norms of the eigenpair approximations           *
C*    W     : work array                                               *
C*    Q     : Lanczos vector                                           *
C*    R     : H*Q                                                      *
C*    BASIS : stores the Lanczos vectors                               *
C*    X     : eigenvector approximations                               *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    HLREND,HLRITZ,HLPSET,HLSTEP                                      *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          INFO(*),LFLAG,LPSET(*)
      COMPLEX*16       BASIS(*),Q(*),R(*),X(*)
      DOUBLE PRECISION EIG(*),HNRM,RNRM(*),W(*)
C
C==== local variables ==================================================
C
      INTEGER          IW(6),JL,JLMAX,JT,JTMAX,LBLAS(4),LN,LPRNT,
     &  	       LRERR,LWARN,N,NCEIG,NREIG,NRORT,NVB
      DOUBLE PRECISION EPS,EPS1,REPS
C
      SAVE             EPS,EPS1,IW,JL,JLMAX,JT,JTMAX,LBLAS,LN,LPRNT,
     &                 LRERR,LWARN,N,NCEIG,NREIG,NRORT,NVB,REPS
C
      LOGICAL          LOCKED /.TRUE./
      SAVE             LOCKED
C
C**** executable statements ********************************************
C
      IF      ( LOCKED .AND. LFLAG.NE.0 ) THEN
C
C............ invalid flag .............................................
C
              LRERR = 2**01
C
      ELSE IF ( LFLAG .EQ. 0 ) THEN
C
              LPRNT = 0           
              LRERR = 0           
              LWARN = 0           
C
C............ start-up .................................................
C
              CALL HLPSET (IW,JL,JLMAX,JTMAX,LBLAS,LFLAG,LN,LPRNT,
     &                     LPSET,LRERR,LWARN,N,NCEIG,NREIG,
     &                     NRORT,NVB,Q,EPS,EPS1,REPS,W)
C
              LOCKED = .FALSE.
C
      ELSE IF ( LFLAG .EQ. 1 ) THEN
C
C............ Lanczos step .............................................
C
              CALL HLSTEP (JL,JLMAX,JT,JTMAX,LBLAS,LFLAG,LN,LPRNT,LRERR,
     &                     LWARN,N,NCEIG,NREIG,NRORT,NVB,BASIS,Q,R,HNRM,
     &                     W(IW(1)),W(IW(2)),W(IW(3)),W(IW(4)),W(IW(5)),
     &                     W(IW(6)),EPS,EPS1,REPS,EIG,RNRM)
C
      ELSE IF ( LFLAG .EQ. 3 ) THEN
C
C............ compute the eigenvectors .................................
C
              CALL HLRITZ (JT,JTMAX,LPRNT,LWARN,LN,N,NVB,BASIS,X,R,EPS,
     &                     EIG,RNRM,W(IW(5)),W(IW(4)),W(IW(6)))
C
              INFO(3) = LWARN
C
              RETURN
C
      ELSE
C
C............ invalid flag .............................................
C
              LRERR = LRERR + 2**01
C
      END IF
C      
      IF ( (LFLAG.EQ.2) .OR. (LRERR.NE.0) .OR. (LWARN.NE.0) ) THEN 
C
         CALL HLREND (JL,LFLAG,LPRNT,LRERR,LWARN,LN,N,NCEIG,
     &                NRORT,BASIS,EPS,EIG,RNRM)
C
         LOCKED = LRERR.NE.0
C
      END IF
C
      INFO(1) = JL   
      INFO(2) = NCEIG
      INFO(3) = LWARN
      INFO(4) = LRERR
C      
      RETURN  
C
C**** end of HLZDRD ****************************************************
C
      END
