      SUBROUTINE IMTQL (LINE,N,D,E,Z,EPS,CONV)
C
C**** adapted from prodecure IMTQL, written by A. DUBRULLE et alii *****
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    IMTQL finds the eigensolutions of a symmetric tridiagonal matrix *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    LINE (sii) : specifies the part of (Z) to be taken into account  *
C*    N    (sii) : dimension of the tridiagonal matrix                 *
C*    D    (arb) : diagonal elements of the tridiagonal matrix         *
C*    E    (arb) : superdiagonal elements of the tridiagonal matrix    *
C*                 eigenvalues in ascending order on output            *
C*    Z    (arb) : previous orthogonal transformation of the matrix    *
C*                 eigenvectors columnwise on output                   *
C*    EPS  (sri) : roundoff unit                                       *
C*    CONV (slo) : flag to indicate convergence                        *
C*                                                                     *
C*  - INTRINSIC FUNCTIONS :                                            *
C*    DABS,DSQRT                                                       *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          LINE,N
      LOGICAL          CONV
      DOUBLE PRECISION D(N),E(N),EPS,Z(N,N)
C
C==== local variables ==================================================
C
      INTEGER          I,ITER,ITMAX,J,K,L,M 
      DOUBLE PRECISION C,H,P,Q,S,T,U
C
      PARAMETER        (ITMAX=50)
C
C==== intrinsic functions ==============================================
C
      INTRINSIC        DABS,DSQRT
C
C**** executable statements ********************************************
C
      CONV = .FALSE.
C
      DO 010 J = 1,N
C
         ITER = 0
C
  070    CONTINUE
C
         DO 030 M = J,N-1
            IF (DABS(E(M)).LE.EPS*(DABS(D(M))+DABS(D(M+1)))) GO TO 040
  030    CONTINUE
C
         M = N
C
  040    CONTINUE
C
         U = D(J)
C
         IF ( M .NE. J ) THEN
C
            IF ( ITER .EQ. ITMAX ) GO TO 080
C
            ITER = ITER + 1
C
            Q = (D(J+1)-U)/(2*E(J))
            T = DSQRT(1.0D0+Q**2)
            IF ( Q .LT. 0.0D0 ) THEN
               Q = D(M) - U + E(J)/(Q-T)
            ELSE
               Q = D(M) - U + E(J)/(Q+T)
            END IF
            U = 0.0D0
            S = 1.0D0
            C = 1.0D0
C
            DO 050 I = M-1,J,-1
C
               P = S*E(I)
               H = C*E(I)
C
               IF ( DABS(P) .GE. DABS(Q) ) THEN
                  C = Q/P
                  T = DSQRT(1.0D0+C**2)
                  E(I+1) = P*T
                  S = 1.0D0/T
                  C = C*S
               ELSE
                  S = P/Q
                  T = DSQRT(1.0D0+S**2)
                  E(I+1) = Q*T
                  C = 1.0D0/T
                  S = S*C
               END IF
C
               Q = D(I+1) - U
               T = (D(I)-Q)*S + 2*C*H
               U = S*T
               D(I+1) = Q + U
               Q = C*T - H
C
               DO 060 L = LINE,N
                  P = Z(L,I+1)
                  Z(L,I+1) = S*Z(L,I) + C*P
                  Z(L,I) = C*Z(L,I) - S*P
  060          CONTINUE
C
  050       CONTINUE
C
            D(J) = D(J) - U
            E(J) = Q
            E(M) = 0.0D0
C
            GO TO 070
C
         END IF
C
  010 CONTINUE
C
      DO 090 I = 1,N
         K = I
         P = D(I)
         DO 100 J = I+1,N
            IF ( D(J) .LT. P ) THEN
               K = J
               P = D(J)
            END IF
  100    CONTINUE
         IF ( K .NE. I ) THEN
            D(K) = D(I)
            D(I) = P
            DO 110 L = LINE,N
               P = Z(L,I)
               Z(L,I) = Z(L,K)
               Z(L,K) = P
  110       CONTINUE
         END IF
  090 CONTINUE
C
      CONV = .TRUE.
C
  080 RETURN
C
C**** end of IMTQL *****************************************************
C
      END
