      SUBROUTINE MGRAMS (LBLAS,N,NVB,BETA,R)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    MGRAMS performs a factorization of (R) into (Q)*(BETA)           *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    LBLAS (sii) : BLAS level setting                                 *
C*    N     (sii) : dimension of each vector                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*    BETA  (aco) : matrix (BETA) in (R)=(Q)*(BETA) at j-th step       *
C*    R     (acb) : residual vector(s) - Lanczos vector(s)             *
C*                                                                     *
C*  - BLAS kernels :                                                   *
C*    ZAXPY,ZDOTC,ZGEMV,ZGERU,ZSCAL                                    *
C*                                                                     *
C*  - INTRINSIC FUNCTIONS :                                            *
C*    DBLE,DCMPLX,DSQRT                                                *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          LBLAS,N,NVB
      COMPLEX*16       BETA(NVB,NVB),R(N,NVB)
C
C==== local variables ==================================================
C
      INTEGER          I,J
      COMPLEX*16       CMPLX0,CMPLX1,ZETA
      DOUBLE PRECISION DIAG
C
C==== BLAS kernel ======================================================
C
      COMPLEX*16       ZDOTC
C
C==== intrinsic functions ==============================================
C
      INTRINSIC        DBLE,DCMPLX,DSQRT
C
C**** executable statements ********************************************
C
      CMPLX0 = ( 0.0D0, 0.0D0 )
      CMPLX1 = ( 1.0D0, 0.0D0 )
C
      CALL ZSCAL (NVB*NVB,CMPLX0,BETA,1)
C
      DO 010 I = 1,NVB
C
         ZETA = ZDOTC(N,R(1,I),1,R(1,I),1)
         DIAG = DSQRT(DBLE(ZETA))
	 BETA(I,I) = DCMPLX(DIAG,0.0D0)
C
 	 IF ( DIAG .NE. 0.0D0 ) THEN
C
C.......... this vector can be normalized ..............................
C
            ZETA = CMPLX1/BETA(I,I)
            CALL ZSCAL (N,ZETA,R(1,I),1)
C
  	    IF      ( LBLAS .EQ. 1 ) THEN
C
C.................. modified Gram-Schmidt using BLAS 1 .................
C
                    DO 020 J = I+1,NVB
                       ZETA = ZDOTC(N,R(1,I),1,R(1,J),1)
                       BETA(I,J) = ZETA
                       CALL ZAXPY (N,-ZETA,R(1,I),1,R(1,J),1)
  020               CONTINUE
C
  	    ELSE IF ( LBLAS .GE. 2 ) THEN
C
C.................. modified Gram-Schmidt using BLAS 2 .................
C
C                   IF ( I .LT. NVB ) THEN
C                      CALL ZGEMV ('T',N,NVB-I,CMPLX1,R(1,I+1),N,R(1,I),
C    &                             1,CMPLX0,BETA(I,I+1),NVB)
C     		       CALL ZGERU (N,NVB-I,-CMPLX1,R(1,I),1,BETA(I,I+1),
C    &  	                   NVB,R(1,I+1),N)
C	            END IF
C
                    STOP
C
	    END IF
C
	 END IF
C
  010 CONTINUE
C
      RETURN
C
C**** end of MGRAMS ****************************************************
C
      END
