      SUBROUTINE QBFCTR (JL,JLMAX,LBLAS,LWARN,N,NVB,BETA,R,DELTA,
     &                   ENORM,WORK,AMAXN,BMAXN,BMINN,EPS)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    QBFCTR monitors the factorization (R)=(Q)*(BETA), (Q')*(Q)=(I)   *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    JL    (sii) : current step                                       *
C*    JLMAX (sii) : maximum number of steps                            *
C*    LBLAS (aii) : BLAS level setting                                 *
C*    LWARN (sio) : warning message code                               *
C*    N     (sii) : dimension of the problem                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*    BETA  (aci) : matrix (BETA) in (R)=(Q)*(BETA)                    *
C*    R     (acb) : residual vectors transformed to Lanczos vectors    *
C*    DELTA (acw) : matrix (BETA) in each iteration                    *
C*    ENORM (acw) : diagonals of (DELTA)                               *
C*    WORK  (acw) : work array                                         *
C*    AMAXN (sri) : minimum singular value of (ALPHA)                  *
C*    BMAXN (sro) : maximum singular value of (BETA)                   *
C*    BMINN (sro) : minimum singular value of (BETA)                   *
C*    EPS   (sri) : roundoff unit                                      *
C*                                                                     *
C*  - SUBPROGRAMS :                                                    *
C*    MGRAMS,MTXNRM,UDBETA                                             *
C*                                                                     *
C*  - BLAS kernel :                                                    *
C*    ZSCAL                                                            *
C*                                                                     *
C*  - INTRINSIC FUNCTIONS :                                            *
C*    DBLE,DCMPLX                                                      *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          JL,JLMAX,LBLAS,LWARN,N,NVB 
      COMPLEX*16       BETA(NVB,NVB),DELTA(NVB,NVB),
     &                 ENORM(*),R(N,*),WORK(*)
      DOUBLE PRECISION AMAXN,BMAXN,BMINN,EPS
C
C==== local variables ==================================================
C 
      INTEGER          I,J,K
      COMPLEX*16       CZERO
      DOUBLE PRECISION GSTOL,THRSH
      LOGICAL          REPEAT
C
C==== intrinsic functions ==============================================
C 
      INTRINSIC        DBLE,DCMPLX
C
C**** executable statements ********************************************
C
      CZERO = ( 0.0D0, 0.0D0 )
      THRSH = EPS**0.75
C
C.... GSTOL as suggested by Daniel, Cragg, Kaufman and Stewart .........
C
      GSTOL = 0.707107D0
C
C.... factorization repeated up to nvb*2 times, if necessary ...........
C
      DO 010 I = 1,NVB*2
C
C....... modified Gram-Schimdt factorization ...........................
C
         CALL MGRAMS (LBLAS,N,NVB,DELTA,R)
C
         CALL UDBETA (NVB,BETA,DELTA)
C
         IF ( I .EQ. 1 ) THEN
            REPEAT = ( NVB .GT. 1 )
            DO 020 J = 1,NVB
               ENORM(J) = DELTA(J,J)
  020       CONTINUE
         ELSE
            REPEAT = .FALSE.
            DO 030 J = 1,NVB
	       IF ( DBLE(DELTA(J,J)) .LT. DBLE(ENORM(J))*GSTOL )
     &              REPEAT = .TRUE.
	            ENORM(J) = DELTA(J,J)
  030       CONTINUE
         END IF
C
         IF ( ( .NOT.REPEAT ) .OR. ( I .EQ. NVB*2 ) ) THEN
C
C.......... check the conditioning of (BETA) ...........................
C
	    CALL MTXNRM (NVB,BETA,WORK,EPS,BMAXN,BMINN) 
C
            IF ( ( JL.LT.JLMAX ) .AND.
     &           ( (BMAXN.LE.AMAXN*THRSH).OR.(BMINN.LE.BMAXN*THRSH) ) )
     &           THEN
C
               LWARN = LWARN + 2**01
C
C............. look for null vectors ...................................
C
               DO 040 J = 1,NVB
                  IF ( DBLE(BETA(J,J)) .LT. THRSH ) THEN
	             DO 050 K = J,NVB  
	                BETA(J,K) = CZERO
  050                CONTINUE
	             CALL ZSCAL (N,CZERO,R(1,J),1)
	             BETA(J,J) = DCMPLX(EPS,0.0D0)
	          END IF
  040          CONTINUE
C
            END IF
C
            RETURN    
C
         END IF
C
  010 CONTINUE
C
      RETURN
C
C**** end of QBFCTR ****************************************************
C
      END
