      SUBROUTINE QTBR (Q,R,ALPHA,AMAX,LBLAS,N,NVB)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    QTBR computes (ALPHA)=(Q')*(R)                                   *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    Q     (aci) : Lanczos  vector(s)                                 *
C*    R     (aci) : residual vector(s)                                 *
C*    ALPHA (aco) : (Q')*(R)                                           *
C*    AMAX  (sro) : largest absolute value in (ALPHA)                  *
C*    LBLAS (sii) : BLAS level setting                                 *
C*    N     (sii) : dimension of each vector                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*                                                                     *
C*  - BLAS kernels :                                                   *
C*    ZDOTC,ZGEMM,ZGEMV                                                *
C*                                                                     *
C*  - INTRINSIC FUNCTION :                                             *
C*    CDABS                                                            *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          LBLAS,N,NVB 
      COMPLEX*16       ALPHA(NVB,NVB),Q(N,NVB),R(N,NVB)
      DOUBLE PRECISION AMAX
C
C==== local variables ==================================================
C
      INTEGER          I,J
      COMPLEX*16       CMPLX0,CMPLX1
C
C==== BLAS kernel ======================================================
C
      COMPLEX*16       ZDOTC
C
C==== intrinsic function ===============================================
C
      INTRINSIC        CDABS
C
C**** executable statements ********************************************
C
      CMPLX0 = ( 0.0D0, 0.0D0 )
      CMPLX1 = ( 1.0D0, 0.0D0 )
C
      IF      ( LBLAS .EQ. 1 ) THEN
C
C............ (Q')*(R) using BLAS 1 ....................................
C
              DO 010 I = 1,NVB
                 DO 020 J = 1,NVB
                    ALPHA(I,J) = ZDOTC(N,Q(1,I),1,R(1,J),1)
  020            CONTINUE
  010         CONTINUE
C
      ELSE IF ( LBLAS .EQ. 2 ) THEN
C
C............ (Q')*(R) using BLAS 2 ....................................
C
C             DO 030 I = 1,NVB
C                CALL ZGEMV ('C',N,NVB,CMPLX1,Q,N,R(1,I),
C    &                       1,CMPLX0,ALPHA(1,I),1)
C 030         CONTINUE
C
              STOP
C
      ELSE IF ( LBLAS .EQ. 3 ) THEN
C
C............ (Q')*(R) using BLAS 3 ....................................
C
C             CALL ZGEMM ('C','N',NVB,NVB,N,CMPLX1,Q,N,
C    &                    R,N,CMPLX0,ALPHA,NVB)
C
              STOP
C
      END IF
C
C.... find the largest entry in ALPHA ..................................
C
      AMAX = ALPHA(1,1)
C
      DO 040 I = 1,NVB
         DO 050 J = 1,NVB
            IF ( CDABS(ALPHA(I,J)) .GT. AMAX ) AMAX = CDABS(ALPHA(I,J))
  050    CONTINUE
  040 CONTINUE
C
      RETURN
C
C**** end of QTBR ******************************************************
C
      END
