      DOUBLE PRECISION FUNCTION RESNRM (N,BETA,S)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    RESNRM computes the residual norm of a Ritz pair calculated      *
C*    through the eigenproblem (TB)*(s)=(s)*teta at j-th step          *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    N    (sii) : dimension of (BETA)                                 *
C*    BETA (ari) : matrix (BETA) in (R)=(Q)*(BETA) at j-th step        *
C*    S    (ari) : bottom N elements of an eigenvector (s) of (TB)     *
C*                                                                     *
C*  - INTRINSIC FUNCTION :                                             *
C*    DSQRT                                                            *
C*                                                                     *
C***********************************************************************
C     
C==== arguments ========================================================
C
      INTEGER          N
      DOUBLE PRECISION BETA(N,N),S(N)
C
C==== local variables ==================================================
C
      INTEGER          I,J
      DOUBLE PRECISION SUM
C
C==== intrinsic function ===============================================
C
      INTRINSIC        DSQRT
C
C**** executable statements ********************************************
C
C     bjnorm_i = || (BETA)*(S)_i ||
C
      RESNRM = 0.0D0
C
C.... multiply (BETA) by (S) and store in RESNRM .......................
C
      DO 010 I = 1,N
         SUM = 0.0D0
         DO 020 J = I,N
            SUM = SUM + BETA(I,J)*S(J)
  020    CONTINUE
         RESNRM = RESNRM + SUM*SUM
  010 CONTINUE
C
C.... the residual norm is the square root .............................
C
      IF ( RESNRM .GT. 1.0D-50 ) THEN
         RESNRM = DSQRT(RESNRM)
      ELSE
         RESNRM = 1.0D-25 
      END IF
C
      RETURN
C
C**** end of RESNRM ****************************************************
C
      END
