      SUBROUTINE RQALPH (R,Q,ALPHA,LBLAS,N,NVB)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    RQALPH computes (R)=(R)-(Q)*(ALPHA)                              *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    R     (acb) : residual vector(s)                                 *
C*    Q     (aci) : current Lanczos vector(s)                          *
C*    ALPHA (aci) : (Q')*(R)                                           *
C*    LBLAS (sii) : BLAS level setting                                 *
C*    N     (sii) : dimension of each vector                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*                                                                     *
C*  - BLAS kernels :                                                   *
C*    ZAXPY,ZGEMM,ZGEMV                                                *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER    LBLAS,N,NVB
      COMPLEX*16 ALPHA(NVB,NVB),Q(N,NVB),R(N,NVB)
C
C==== local variables ==================================================
C 
      INTEGER    I,J
      COMPLEX*16 CMPLX1
C
C**** executable statements ********************************************
C
      CMPLX1 = ( 1.0D0, 0.0D0 )
C
      IF      ( LBLAS .EQ. 1 ) THEN
C
C............ (R)=(R)-(Q)*(ALPHA) using BLAS 1 .........................
C
              DO 010 I = 1,NVB
                 DO 020 J = 1,NVB
                    CALL ZAXPY (N,-ALPHA(J,I),Q(1,J),1,R(1,I),1)
  020            CONTINUE
  010         CONTINUE
C
      ELSE IF ( LBLAS .EQ. 2 ) THEN
C
C............ (R)=(R)-(Q)*(ALPHA) using BLAS 2 .........................
C
C             DO 030 I = 1,NVB
C                CALL ZGEMV ('N',N,NVB,-CMPLX1,Q,N,ALPHA(1,I),1,
C    &                       CMPLX1,R(1,I),1)
C 030         CONTINUE
C
              STOP
C
      ELSE IF ( LBLAS .EQ. 3 ) THEN
C
C............ (R)=(R)-(Q)*(ALPHA) using BLAS 3 .........................
C
C             CALL ZGEMM ('N','N',N,NVB,NVB,-CMPLX1,Q,N,
C    &                    ALPHA,NVB,CMPLX1,R,N)
C
              STOP
C
      END IF 
C
      RETURN
C
C**** end of RQALPH ****************************************************
C
      END
