      SUBROUTINE RQBETA (R,Q,BETA,LBLAS,N,NVB)
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    RQBETA computes (R)=(R)-(Q)*(BETA')                              *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    R     (acb) : residual vector(s)                                 *
C*    Q     (aci) : Lanczos  vector(s) at previous step                *
C*    BETA  (aci) : matrix (BETA) in (R)=(Q)*(BETA) at step JL-1       *
C*    LBLAS (sii) : BLAS level setting                                 *
C*    N     (sii) : dimension of each vector                           *
C*    NVB   (sii) : number of vectors in a block                       *
C*                                                                     *
C*  - BLAS kernels :                                                   *
C*    ZAXPY,ZGEMV                                                      *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER    LBLAS,N,NVB
      COMPLEX*16 BETA(NVB,NVB),Q(N,NVB),R(N,NVB)
C
C==== local variables ==================================================
C 
      INTEGER    I,J
      COMPLEX*16 CMPLX1
C 
C**** executable statements ********************************************
C
      CMPLX1 = ( 1.0D0, 0.0D0 )
C
      IF      ( LBLAS .EQ. 1 ) THEN
C
C............ (R)=(R)-(Q)*(BETA') using BLAS 1 .........................
C
              DO 030 I = 1,NVB
                 DO 040 J = I,NVB
                    CALL ZAXPY (N,-BETA(I,J),Q(1,J),1,R(1,I),1)
  040            CONTINUE
  030         CONTINUE
C
      ELSE IF ( LBLAS .GE. 2 ) THEN
C
C............ (R)=(R)-(Q)*(BETA') using BLAS 2 .........................
C
C             J = NVB
C
C             DO 050 I = 1,NVB
C                CALL ZGEMV ('N',N,J,-CMPLX1,Q(1,I),N,BETA(I,I),
C    &                       NVB,CMPLX1,R(1,I),1)
C                J = J - 1
C 050         CONTINUE
C
              STOP
C
      END IF 
C
      RETURN
C
C**** end of RQBETA ****************************************************
C
      END
