      SUBROUTINE UPDETA (J,AMAXN,BMAXN,BMINN,EPS1,ETAQ,ETAR) 
C
C***********************************************************************
C*                                                                     *
C*  - PURPOSE :                                                        *
C*    UPDETA updates bounds for the partial reorthog. strategy         *
C*                                                                     *
C*  - ARGUMENTS :                                                      *
C*    J     (sii) : current number of steps                            *
C*    AMAXN (ari) : Euclidian norms of (ALPHA)                         *
C*    BMAXN (ari) : Euclidian norms of (BETA)                          *
C*    BMINN (sri) : minimum norm of current (BETA)                     *
C*    EPS1  (sri) : roundoff unit * sqrt(N)                            *
C*    ETAQ  (arb) : orthog. bounds among (Q) and Lanczos vectors       *
C*    ETAR  (arb) : orthog. bounds among (R) and Lanczos vectors       *
C*                                                                     *
C***********************************************************************
C*                                                                     *
C*    eta_(j+1,i) = { [||alpha_(i)||+||alpha_(j)||]*eta_(j,i) +        *
C*                    ||beta_(i+1)||*eta_(j  ,i+1) +                   *
C*                    ||beta_(  i)||*eta_(j  ,i-1) +                   *
C*                    ||beta_(  j)||*eta_(j-1,i  ) } / ||beta_(j+1)||  *
C*                                                                     *
C***********************************************************************
C
C==== arguments ========================================================
C
      INTEGER          J
      DOUBLE PRECISION AMAXN(*),BMAXN(*),BMINN,EPS1,ETAQ(*),ETAR(*)
C
C==== local variables ==================================================
C
      INTEGER          I
      DOUBLE PRECISION TEMP
C
C**** executable statements ********************************************
C
      IF ( J .LT. 3 ) RETURN
C
         ETAR(  J) = EPS1
C
         ETAR(J-1) = ( (AMAXN(J)+AMAXN(J-1))*EPS1 + 
     &                 BMAXN(J-1)*ETAQ(J-2) +
     &                 BMAXN(  J)*EPS1*2.00 ) / BMINN
C
         ETAQ(  1) = ( (AMAXN(1)+AMAXN(J))*ETAR(1) +
     &                 BMAXN(  2)*ETAR(  2) +
     &                 BMAXN(  J)*ETAQ(  1) ) / BMINN
C
      DO 010 I = 2,J-2
         ETAQ(  I) = ( (AMAXN(I)+AMAXN(J))*ETAR(I) +
     &                 BMAXN(I+1)*ETAR(I+1) +
     &                 BMAXN(  I)*ETAR(I-1) + 
     &                 BMAXN(  J)*ETAQ(  I) ) / BMINN
  010 CONTINUE
C
      DO 020 I = 1,J-2
         TEMP    = ETAQ(I)
         ETAQ(I) = ETAR(I)
         ETAR(I) = TEMP
  020 CONTINUE
C
      RETURN
C
C**** end of UPDETA ****************************************************
C
      END
